summaryrefslogtreecommitdiff
path: root/Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs')
-rw-r--r--Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs34
1 files changed, 4 insertions, 30 deletions
diff --git a/Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs b/Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs
index 6668f8d7..060a1212 100644
--- a/Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs
+++ b/Xamarin.Forms.Platform.Tizen/Native/LayoutEventArgs.cs
@@ -1,4 +1,5 @@
using System;
+using ElmSharp;
namespace Xamarin.Forms.Platform.Tizen.Native
{
@@ -17,39 +18,12 @@ namespace Xamarin.Forms.Platform.Tizen.Native
}
/// <summary>
/// X coordinate of the layout area, relative to the main window.
/// </summary>
- public int X
+ public Rect Geometry
{
get;
- internal set;
- }
-
- /// <summary>
- /// Y coordinate of the layout area, relative to the main window.
- /// </summary>
- public int Y
- {
- get;
- internal set;
- }
-
- /// <summary>
- /// Width of the layout area.
- /// </summary>
- public int Width
- {
- get;
- internal set;
- }
-
- /// <summary>
- /// Height of the layout area.
- /// </summary>
- public int Height
- {
- get;
- internal set;
+ set;
}
}
}
@@ -17,39 +18,12 @@ namespace Xamarin.Forms.Platform.Tizen.Native
}
/// <summary>
- /// X coordinate of the layout area, relative to the main window.
+ /// Geometry of the layout area, absolute coordinate
/// </summary>